package com.yunfeiyun.agmp.fms.service;

import com.yunfeiyun.agmp.common.core.domain.AjaxResult;
import com.yunfeiyun.agmp.fms.domain.MppQualitycheck;
import com.yunfeiyun.agmp.fms.domain.reqvo.AddMppQualitycheckReqVo;

import java.util.List;


/**
 *  质检Service接口
 * 
 * @author 杨晓辉
 * @date 2023-05-30
 */
public interface IMppQualitycheckService 
{
    /**
     * 查询 质检
     * 
     * @param qualitycheckId  质检主键
     * @return  质检
     */
    public MppQualitycheck selectMppQualitycheckByQualitycheckId(String qualitycheckId);

    /**
     * 查询 质检列表
     * 
     * @param mppQualitycheck  质检
     * @return  质检集合
     */
    public List<MppQualitycheck> selectMppQualitycheckList(MppQualitycheck mppQualitycheck);

    /**
     * 新增 质检
     * 
     * @param mppQualitycheck  质检
     * @return 结果
     */
    public AjaxResult insertMppQualitycheck(AddMppQualitycheckReqVo reqVo);

    /**
     * 修改 质检
     * 
     * @param mppQualitycheck  质检
     * @return 结果
     */
    public int updateMppQualitycheck(MppQualitycheck mppQualitycheck);

    /**
     * 批量删除 质检
     * 
     * @param qualitycheckIds 需要删除的 质检主键集合
     * @return 结果
     */
    public int deleteMppQualitycheckByQualitycheckIds(String[] qualitycheckIds);

    /**
     * 删除 质检信息
     * 
     * @param qualitycheckId  质检主键
     * @return 结果
     */
    public int deleteMppQualitycheckByQualitycheckId(String qualitycheckId);
}
